#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-Bl10zXgZJE7SOaBa4UWf1
key:                  stack-2.9.3.1-Bl10zXgZJE7SOaBa4UWf1
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  9ed7d2f63a94d4b3760c7a844d94ab47
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-Bl10zXgZJE7SOaBa4UWf1
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-EjtcViUIVMXBXClGtNnj1W
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-G6GN5PMYp5NGFUNAfhx5GN array-0.5.6.0
    async-2.2.6-9SkVXCaD6xtG9Q9oLNb0PF
    attoparsec-0.14.4-FNfFcxBCxLE3gVrmuo10Xu base-4.18.2.1
    base64-bytestring-1.2.1.0-3sV69hgoSWS1a2SgImTi0f
    bytestring-0.11.5.3 casa-client-0.0.4-GNiSr017U5L5n5O8BoB8O6
    casa-types-0.0.3-6jH5Ze9elxHBhGFeQaRXJ3
    colour-2.3.7-2i2xCShEaZPHWd8ZVrjBjE
    conduit-1.3.6.1-6RhtQrDCVyFKlfTW6yY8Y8
    conduit-extra-1.3.8-6Aunv0UCACaxQftojlLnM containers-0.6.7
    crypton-1.0.5-FKWxP7ZgU3GEWOeuExdjSh
    crypton-conduit-0.2.3-35JBY8SzRCOKfwztdAZAy9 deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-4wSkYVL2nSPIREYNkKCrdu
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.9-8ziNPZUbIkwAKhIV8O0ACv filepath-1.4.300.1
    fsnotify-0.4.4.0-HbfcQMlpGSg8B9abhNIBl3
    generic-deriving-1.14.7-ILXoQm3PcWF55Q00zCdsSX
    hackage-security-0.6.3.2-3486XtvlbqZ5ng7F2JhiWn
    hashable-1.4.7.0-IundBnRd4VH238tCbJShYq
    hi-file-parser-0.1.8.0-9UPnnCcnJAZ2LoCd2IFEiG
    hpack-0.38.0-IQowaiG6Wk53stN9keJzK hpc-0.6.2.0
    http-client-0.7.19-87p4cjUWLSQ2b1eq95JNyo
    http-client-tls-0.3.6.4-GB2ge6JmZ9r9eiHdsIvObg
    http-conduit-2.3.9.1-Ap2uK7IYPjcEcaT5i0fEbs
    http-download-0.2.1.0-4wCw7ls9nhAR7nUtzVHp2
    http-types-0.12.4-JnrWvg31Xm49lqVV9Lcvtr
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-FrsKcbyyE4Y4HoIbORdfNV mtl-2.3.1
    mustache-2.4.3.1-1XFnwxZuhPxDh4fdrR6CMZ
    neat-interpolation-0.5.1.4-DaNMmxVLKF4A2YAmNEZUxB
    network-uri-2.6.4.2-5HHIVGX9T5J8Uh7pHWoHCS
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-72ySYnQcAhaEf71plWxl77
    pantry-0.8.3-3ocvMZlKmmQFNujGtnYVD7
    path-0.9.6-4r3OPu1I7VV4bnjWaogZ9q
    path-io-1.8.2-FzIUihY9tac6mR1M7Htnit
    persistent-2.14.6.1-GSkhBnL5ygC61RNhD7bs9B
    persistent-sqlite-2.13.3.0-4bLDB34PUwM7OeDIC0OWwi pretty-1.1.3.6
    primitive-0.9.1.0-7BU3lI8ZSpRANXT28DiNLA process-1.6.19.0
    project-template-0.2.1.0-FJHNATcRSILcutgP1250P
    random-1.2.1.3-8T7wlm0rQ0t5wVCdHG7g6D
    retry-0.9.3.1-CpbKJFWIi9X8kTggH29boq
    rio-0.1.25.0-9tFlGoBvXpv5d0KDA2qtut
    rio-prettyprint-0.1.9.0-KIHKjrp5uKfCatpFflNC8E
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl stm-2.5.1.0
    streaming-commons-0.2.3.1-GXUAG5vNvztDDF8XVgsdY6
    tar-0.6.0.0-GRQs7xY7GUq2H1oPnGU9WR template-haskell-2.20.0.0
    temporary-1.3-KFCBkNo4bT62JaFUCHAGBl text-2.0.2
    text-metrics-0.3.3-BFzjYkHiQpTJ8DZdH8Bsws
    th-reify-many-0.1.10-7danJ8Mwk9F1awIriDvx7g time-1.12.2
    tls-2.0.6-JINOC8WKM7PEITB4mU31jV transformers-0.6.1.0
    typed-process-0.2.13.0-Dfig2CH9X0Q5cI9bXZXAQ9
    unicode-transforms-0.4.0.1-77jg2WKbNvodyr7K4cbod unix-2.8.4.0
    unix-compat-0.7.4.1-8VCJ8rV551MF5eFV42xIXe
    unliftio-0.2.25.1-DscakO0OUYTI6rllvWargg
    unordered-containers-0.2.21-6KS41JVoQWZ5mM86HX5ZiJ
    vector-0.13.2.0-CGL8pnIxGMbHvZ63ZDtObP
    yaml-0.11.11.2-IH0VYTSwxUVGn02SeZB1Z
    zip-archive-0.4.3.2-CpwBawMeecj7gh70NgDjUv
    zlib-0.7.1.0-EKJDtvQuV7pGDuMchj7LlO

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

